#Film Collection Site - Technical Details

##Description

This site displays the contents of an [ANT Movie Catalog](http://www.antp.be/software/moviecatalog) XML file in various ways. It also permits minor editing of films of the catalog.

All code is in *php 5.3*. The *[mootools 1.4.](http://mootools.net/)* javascript library is heavily used.

This is a single-page site. All calls are done using *ajax*.

When the page *index.php* is requested from the server the following happen:

- Firstly the *XML ANT Movie Catalog* file is parsed and several data lists are formed, the main being the *movies* list, an array of *movie* objects. All lists are stored in the *$_SESSION* variable so that they are accessible by other php files. The XML file is not re-read and lists are *not* recreated *until the browser is closed*, unless actively *Reloaded* (see below)
- Subsequently, the main page *index.php* is displayed with its menus and an ajax call is done to fetch the output of *help.php*
- The top menu bar has options to invoke films from the catalog. The films are displayed as thumbnails that allow access the the corresponding information
- A click on a thumbnail fetches the corresponding film information
- All links are processed with ajax calls.
- All requested php files reference the *$_SESSION* variable to access the data lists

Note:

>Pictures of films are expected in the folder created when exporting from the AMC application. Thumbnails are created by the program when needed and are stored in a separate sub-folder. Creation is done once. If a picture has changed since the creation of the thumbnail, there is an option to recreate it (see below).

##Files used

####Data files

- the *XML file* as created by the *ANT Movie Catalog*, e.g. *films.xml*. It must be in the **root** folder

    Note that two custom fields are assumed: 
    - *location*: which indicates a location (e.g. drawer, box, etc.) where the movie is stored. A pathname may be used if the movie is stored in a folder or file
    - *seen*: a boolean flag to indicate whether the movie has been seen or not

- the *folder with the film pictures* as created by the *ANT Movie Catalog*, e.g. *films.xml_pics*

    Note that each movie entry references the corresponding image pathname. Ensure that the path is correct

####Program files

- *config.php* - the configuration file; at present just the name of the XML file and the *owner* and *groupname* for the xml file and thumbnails
- *default.css* - the stylesheet file
- *editMovie.php* - the movie editor; it uses *parserNew.php* and *thumbs.php*
- *eraseLists.php* - used to reload data from the xml file
- *functions.php* - several utility functions referenced in *parserNew.php*
- *head.php* - the header file used by all display files in the html head section. It contains script tags for the mootools library from *ajax.googleapis.com*, for the *mootools-more* file (see below) and the *main.js* file (see below)
- *help.php* - the help/stats file; it uses *parserNew.php*
- *index.php* - the main file; it uses *parserNew.php*
- *list.php* - the file that produces lists; it uses *parserNew.php*
- *loading.gif* - the loading gif used by ajax calls, referenced in *default.css*
- *main.js* - the main javascript file
- *mootools-more-1.4.0.1.js* - some additional functions needed by the mootools javascript code; referenced by *head.php*
- *movie.php* - displays details of a single movie; it uses *parserNew.php* and *thumbs.php*
- *movies.php* - displays thumbnails of movies; it uses *parserNew.php* and *thumbs.php*
- *parserNew.php* - reads the XML file and initialises lists. It also contains utility functions for the display of statistics, etc.; referenced by most other php files
- *recreateThumb.php* - regenerates a thumbnail of a movie picture; it uses *thumbs.php*
- *saveChanges.php* - saves all data in the XML file; it uses *parserNew.php*
- *thumbs.php* - creates thumbnails; used by *movies.php* and *movie.php*
- *updateMovie.php* - updates the movie data with changes after edit - uses *parserNew.php*
- *updateSeen.php* - updates the seen attribute of a movie

####Auxiliary files

- folder *gfx* contains icons of stars for the display of ratings - used by *movie.php*
- folder *mc* contains code that allows copying stuff to clipboard - used by *movie.php*

##Functionality

The main menu contains the following options:

- *All Films* - which fetches thumbnails of all films - it invokes *movies.php*. The thumbnails are links to the corresponding details - they invoke *movie.php* to display details of the film
- *Directors* - which fetches a list the names of all directors in all films - it invokes *list.php*. The names are links that fetch the thumbnails of the films of the corresponding director, as above.
- *Categories* - similar to the above for categories
- *Countries* - similar to the above for countries
- *Years* - similar to the above for years
- *Ratings* - similar to the above for ratings. Ratings are integers from 0 to 10. Each number is a link to the thumbnails of the films with the nearest rating.
- *Dates* - similar of the above for the dates, i.e. the dates the films were added to the database
- *Media* - similar to the above for media types, i.e. AVI, DVD, MKV, etc.
- *Help/Stats* - invokes the help/stats page
- *Search* - in *Titles*, *Directors* or *Actors*

The bottom bar contains links that:

- *Expand* or *Contract* the thumbnail area. The expanded option occupies the entire page
- Select the *Size* of thumbnails: *small* or *large*
- Permits grouping of the thumbnails as follows:
	- No group - for no grouping
	- Directors
	- Categories
	- Countries
	- Years
	- Ratings
	- Dates
	- Media

	When any of the grouping options is selected then the thumbnail pane is rendered in corresponding sections.

##Administrator Mode

If the site is accessed from the same LAN, i.e. if the server IP address starts with 192.168 or 10. etc., then the following extra features are enabled:

####Reload Data

A *Reload* option appears on the bottom toolbar which reloads the XML file. Useful if the the file has been changed since the site was loaded. The alternative way to reload data is to close and reopen the *browser* to start a new session.

####Edit a Film

When the details of one film are displayed by clicking on a thumbnail on the left pane, the following options are available at the right-hand side of bottom bar:

- *Edit* - It displays a form to edit certain fields. After the changes are submitted the data kept in memory are updated accordingly. Then, the following option is available:
- *Save* - It makes a backup of the XML file and saves the contents of the data in the file. The file is completely compatible with the *ANT Movie Catalog*
- *Thumb* - It recreates the thumb of the film shown. Useful if the picture of the film has changed.

##Limitations

The entire XML file is read in one go. The current file-size is near 800kb and this isn't a problem at all. Apparently for much bigger files there's going to be a memory overflow problem.

##Further work

- A *seen* boolean field in the database has been added. The output XML file when read by the *ANT Movie Catalog* it think it is string. Not a serious problem
- Load thumbnails "as needed", not all at once
- The single page structure with ajax does not register history on the browser. There are some ways of doing this. To be investigated
- What happens when the database is very "big"? Paging is perhaps a way to go, but this will most certainly lead to a complete redesign of the application

##Acknowledgment

Three functions in *parserNew.php*, namely functions *parseFile*, *startElement* and *endElement* are modified versions of the corresponding functions of the code in [AMCphp - a php template for the *ANT Movie Catalog*](http://amc.loben.net). The star rating feature has also been taken from that site. 

##Contact

<pmoukas@gmail.com>

<http://boubouni.com>

<p style="text-align: right">Athens 10/3/2013</p>
